---
description: >-
  포트원 이용절차 중 실연동에 관련된 안내입니다. 결제대행사와 계약을 맺으신 후 운영환경 반영이 가능합니다. 미리 확인해야할 사항들을
  체크해보세요.
title: 실 연동
category: 포트원 이용절차 (온보딩 가이드) > 결제 연동 > 실연동
seo:
  title: 실 연동
tags:
  - 공통
  - 실 연동
pgCompanies:
  - 공통
searchTags:
  - 운영환경
  - 실운영
  - 채널설정
  - 연동방법
  - 실연동
---



<Callout content="실 운영 환경은 결제대행사와 계약완료 및 카드사 심사까지 완료된 이후 반영해주셔야 합니다." title="" />

### **사전 점검사항**

1. **실 결제는 카드사(원천사) 심사까지 최종적으로 완료되었을 때 가능합니다.**

- 결제대행사와 계약만 완료되고 카드사 심사가 완료되지 않은 경우 실 KEY가 발급 되었을지라도 결제가 이루어지지 않는 것이 정상입니다.
- 최종적으로 마지막 단계인 ‘원천사(카드사, 통신사 등)심사’가 완료된 후 결제대행사(PG)로부터 서비스 사용 안내를 받으셨을 때 실제 결제 승인이 가능합니다.

**2. 테스트 KEY만 운영용 KEY로 바꾸고 바로 서비스 오픈하면 되나요?**

- 카드사 심사가 완료되었다고 안내받으셨을지라도 예상하지 못한 변수로 인하여 결제오류가 발생되거나 내부적으로 구현하시는 로직이 올바르게 동작하지 않을 수 있습니다. 따라서 **서비스를 오픈하기 전 반드시  충분한 테스트를 진행해주시길 권고드립니다.** 또한 테스트환경에서 실 연동환경으로 전환하셨다면 실운영 KEY로 결제가 발생되고 있는지 확인하시어 테스트용 KEY로 서비스가 오픈되지 않도록 유의해주세요.

### **실 연동 채널 설정방법**

심사가 완료된 KEY를 포트원 관리자콘솔에서 설정해주세요.\
연동을 위한 KEY는 결제대행사(PG)에서 계약을 진행하신 담당자님 메일로 안내를 드리고 있습니다.\
아래 가이드를 통해 원하시는 결제대행사의 실 연동 채널 설정방법을 확인해보세요.

<Callout title="결제대행사별 채널설정방법 보러가기↗" content=" " icon="" />
